summaryrefslogtreecommitdiff
path: root/avmedia/source/framework
diff options
context:
space:
mode:
authorArmin Le Grand <alg@apache.org>2014-07-14 19:09:11 +0000
committerArmin Le Grand <alg@apache.org>2014-07-14 19:09:11 +0000
commit3c1d4742e649fe9c8aed8c2817fe3e1f3364f298 (patch)
treee0c6e02c89aa9227726c9469da1001b3e29c41df /avmedia/source/framework
parentc5c31e2aeaedbdf76e1f38d3c385e34f5ed875ca (diff)
Resync to trunk, windows non-pro build aoo/aw080
Diffstat (limited to 'avmedia/source/framework')
-rw-r--r--avmedia/source/framework/soundhandler.cxx10
-rw-r--r--avmedia/source/framework/soundhandler.hxx2
2 files changed, 6 insertions, 6 deletions
diff --git a/avmedia/source/framework/soundhandler.hxx b/avmedia/source/framework/soundhandler.hxx
index 99587f094f16..012e21448065 100644
--- a/avmedia/source/framework/soundhandler.hxx
+++ b/avmedia/source/framework/soundhandler.hxx
@@ -90,7 +90,7 @@ class SoundHandler : // interfaces
, public css::frame::XNotifyingDispatch // => XDispatch
, public css::document::XExtendedFilterDetection
// baseclasses
- // Order is neccessary for right initialization!
+ // Order is necessary for right initialization!
, private ThreadHelpBase
, public ::cppu::OWeakObject
{
diff --git a/avmedia/source/framework/soundhandler.cxx b/avmedia/source/framework/soundhandler.cxx
index b767d049a3c7..158494a2fac9 100644
--- a/avmedia/source/framework/soundhandler.cxx
+++ b/avmedia/source/framework/soundhandler.cxx
@@ -307,12 +307,12 @@ SoundHandler::~SoundHandler()
@short try to load audio file
@descr This method try to load given audio file by URL and play it. We use vcl/Sound class to do that.
- Playing of sound is asynchron everytime.
+ Playing of sound is asynchron every time.
@attention We must hold us alive by ourself ... because we use async. vcl sound player ... but playing is started
in async interface call "dispatch()" too. And caller forget us imediatly. But then our uno ref count
will decreased to 0 and will die. The only solution is to use own reference to our implementation.
- But we do it for realy started jobs only and release it during call back of vcl.
+ But we do it for really started jobs only and release it during call back of vcl.
@seealso class vcl/Sound
@seealso method implts_PlayerNotify()
@@ -391,7 +391,7 @@ void SAL_CALL SoundHandler::dispatch( const css::util::URL&
@attention a) We don't need any mutex here ... because we don't use any member!
b) Dont' use internal player instance "m_pPlayer" to detect given sound file!
- It's not neccessary to do that ... and we can use temp. variable to do the same.
+ It's not necessary to do that ... and we can use temp. variable to do the same.
This way is easy - we don't must synchronize it with currently played sounds!
Another reason to do so ... We are a listener on our internal ma_Player object.
If you would call "IsSoundFile()" on this instance, he would call us back and
@@ -407,7 +407,7 @@ void SAL_CALL SoundHandler::dispatch( const css::util::URL&
*//*-*************************************************************************************************************/
::rtl::OUString SAL_CALL SoundHandler::detect( css::uno::Sequence< css::beans::PropertyValue >& lDescriptor ) throw( css::uno::RuntimeException )
{
// Our default is "nothing". So we can return it, if detection failed or fily type is realy unknown.
::rtl::OUString sTypeName;
// Analyze given descriptor to find filename or input stream or ...
@@ -440,7 +440,7 @@ void SAL_CALL SoundHandler::dispatch( const css::util::URL&
@seealso method dispatchWithNotification()
@param -
- @return 0 everytime ... it doesnt matter for us.
+ @return 0 every time ... it doesn't matter for us.
@onerror -
@threadsafe yes
@@ -407,7 +407,7 @@ void SAL_CALL SoundHandler::dispatch( const css::util::URL&
::rtl::OUString SAL_CALL SoundHandler::detect( css::uno::Sequence< css::beans::PropertyValue >& lDescriptor ) throw( css::uno::RuntimeException )
{
- // Our default is "nothing". So we can return it, if detection failed or fily type is realy unknown.
+ // Our default is "nothing". So we can return it, if detection failed or fily type is really unknown.
::rtl::OUString sTypeName;
// Analyze given descriptor to find filename or input stream or ...